@@ -9,6 +9,7 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
 
 test_that("crm_plain works with links input",{
   skip_on_cran()
+  skip_on_travis()
 
   res <- suppressMessages(crm_plain(link1))
   expect_is(res, "character")
@@ -21,18 +22,19 @@ test_that("crm_plain works with character URL input", {
 
   res <- suppressMessages(crm_plain(url))
   expect_is(res, "character")
-  expect_gt(nchar(res), 100000L)
+  expect_gt(nchar(res), 100L)
   expect_match(res, title)
 })
 
 test_that("crm_plain fails well",{
+  skip_on_cran()
+  
   expect_error(crm_plain(5), "no 'crm_plain' method for numeric")
   expect_error(crm_plain(mtcars), "no 'crm_plain' method for data.frame")
   expect_error(crm_plain(matrix(1:5)), "no 'crm_plain' method for matrix")
 
   expect_error(crm_plain("adfdf"), "Not a proper url")
 
-  skip_on_cran()
   expect_error(crm_plain(link1, overwrite_unspecified = 5),
                "overwrite_unspecified must be of class logical")
 })
